'use strict';

var react = require('react');
var invariant = require('tiny-invariant');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var invariant__default = /*#__PURE__*/_interopDefaultLegacy(invariant);

// Fixing inconsistencies from older browsers
// https://developer.mozilla.org/en-US/docs/Web/API/KeyboardEvent/key/Key_Values
var aliases = new Map([['Win', 'Meta'], ['Scroll', 'ScrollLock'], ['Spacebar', ' '], ['Down', 'ArrowDown'], ['Left', 'ArrowLeft'], ['Right', 'ArrowRight'], ['Up', 'ArrowUp'], ['Del', 'Delete'], ['Crsel', 'CrSel'], ['Exsel', 'ExSel'], ['Apps', 'ContextMenu'], ['Esc', 'Escape'], ['Decimal', '.'], ['Multiply', '*'], ['Add', '+'], ['Subtract', '-'], ['Divide', '/']]);

var shimKeyboardEvent = function shimKeyboardEvent(event) {
  if (aliases.has(event.key)) {
    var key = aliases.get(event.key);
    Object.defineProperty(event, 'key', {
      configurable: true,
      enumerable: true,
      get: function get() {
        return key;
      }
    });
  }
};

var useKeypress = function useKeypress(keys, handler) {
  !(Array.isArray(keys) || typeof keys === 'string') ? process.env.NODE_ENV !== "production" ? invariant__default['default'](false, 'Expected `keys` to be an array or string') : invariant__default['default'](false) : void 0;

  if (Array.isArray(keys)) {
    keys.forEach(function (key, i) {
      !(typeof key === 'string') ? process.env.NODE_ENV !== "production" ? invariant__default['default'](false, "Expected `keys[" + i + "]` to be a string") : invariant__default['default'](false) : void 0;
    });
  }

  !(typeof handler === 'function' || handler == null) ? process.env.NODE_ENV !== "production" ? invariant__default['default'](false, 'Expected `handler` to be a function') : invariant__default['default'](false) : void 0;
  var eventListenerRef = react.useRef();
  react.useEffect(function () {
    eventListenerRef.current = function (event) {
      shimKeyboardEvent(event);

      if (Array.isArray(keys) ? keys.includes(event.key) : keys === event.key) {
        handler == null ? void 0 : handler(event);
      }
    };
  }, [keys, handler]);
  react.useEffect(function () {
    var eventListener = function eventListener(event) {
      eventListenerRef.current(event);
    };

    window.addEventListener('keydown', eventListener);
    return function () {
      window.removeEventListener('keydown', eventListener);
    };
  }, []);
};

module.exports = useKeypress;
//# sourceMappingURL=index.cjs.js.map
